@@ -202,7 +202,12 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
     num_ks = len(data_projected[0,0,:])
     tot_branches = int(len(frequencies_disp[:,0]))
     plt.ion()
-    X, Y = np.meshgrid(kk_many,f)
+    dk = kk_many[1] - kk_many[0]
+    kk_many2 = np.concatenate((kk_many, [kk_many[-1]+dk])) - dk/2
+    kk_many2 = kk_many2 / kk_many[-1]
+    X, Y = np.meshgrid(kk_many2,f)
+    kk_many = kk_many/kk_many[-1]
+    kk = kk/kk[-1]
     
     fig, ax = plt.subplots()
 #    if(len(branches) == tot_branches): #plot whole spectrum
@@ -214,20 +219,23 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
     if(max_Z > np.max(data_projected) or max_Z < 0.0):
         max_Z = np.max(data_projected)
     print('Drawing branches ', branches)
-    ax.contourf(X,Y,np.sum(data_projected, axis=1),100, vmax=max_Z)
+    ax.pcolormesh(X,Y,np.sum(data_projected[:,branches,:], axis=1), vmax=max_Z, cmap='Blues')
     print('finished')
     
     
     ax2 = plt.twinx()
     ax2.set_ylabel('[Thz]')
     for j in branches:
-        graph_disp, = ax2.plot(kk_many, frequencies_disp[j,:], color='black', label='0K dispersion', linewidth=1)
-        # graph_ft, = ax2.plot(kk_many, frequencies_ft[j,:], color='red', label='interp finite dispersion', linewidth=1)
-
+        if(len(kk_many) > len(kk)): # then you are interpolating
+            graph_disp, = ax2.plot(kk_many, frequencies_disp[j,:], color='black', label='0K dispersion', linewidth=1)
+            # graph_ft, = ax2.plot(kk_many, frequencies_ft[j,:], color='red', label='interp finite dispersion', linewidth=1)
+        else:
+            graph_disp = ax2.scatter(kk_many, frequencies_disp[j,:], color='black', label='0K dispersion', linewidth=1)
+            # graph_ft, = ax2.plot(kk_many, frequencies_ft[j,:], color='red', label='interp finite dispersion', linewidth=1)
 
     ax2.get_shared_y_axes().join(ax, ax2)
     plt.ylim([f[0], f[-1]])
-    plt.xlim([kk[0], kk[-1]])
+    plt.xlim([kk_many[0], kk_many[-1]])
     
     plt.xticks(kk,indexes)
     # plt.legend(handles=(graphs[0][0],))#graphs[1][0]
