@@ -397,7 +397,6 @@ if(plot_type==5):
     print('Generating plot 5...')
     # take the path the user inputs and find all the k points you can plot, with interpolation
     ks_scal_path_many, ks_path_many, distances_many = util.get_kpath_many(ks_scaled_path, Hk, npoints=interp+1)
-    num_modes = len(modes)
     K_renorm = np.loadtxt('K_renorm')
 
     freq = np.loadtxt('ZS'+appendix, usecols=0)
@@ -476,7 +475,7 @@ if(plot_type==5):
 
 
     #this is to reshape spectra according to real branches
-    indexes, freqs_reshaped = util.get_real_branches(frequencies, EIGVECS, masses_uc, ks_path_many)
+    indexes, freqs_reshaped = util.get_real_branches(frequencies, EIGVECS_0K, masses_uc, ks_path_many)
     indexes_0K, freqs_disp_reshaped = util.get_real_branches(frequencies_disp, EIGVECS_0K, masses_uc, ks_path_many)
     
     # #this is to reshape spectra according to real branches
@@ -485,15 +484,15 @@ if(plot_type==5):
     frequencies_reshaped, frequencies_disp_reshaped  = np.copy(frequencies), np.copy(frequencies_disp)
     frequencies_reshaped, frequencies_disp_reshaped = freqs_reshaped, freqs_disp_reshaped
     
-    ZQS_proj_reshaped = np.zeros((meta, num_modes, len(ks_path)))
+    ZQS_proj_reshaped = np.zeros((meta, tot_atoms_uc*3, len(ks_path)))
     for j in range(len(ks_path)):
-        ZQS_proj_reshaped[:,:,j] = ZQS_proj[:,indexes[j,modes],j]
+        ZQS_proj_reshaped[:,:,j] = ZQS_proj[:,indexes_0K[j,:],j]
     freqs_from_spectrum = util.freqs_spectrum(freq,ZQS_proj_reshaped)
     
     if (interp>0):
-        ZQS_proj_interp = util.interpol_spectrum(ks_path, freq, freqs_from_spectrum, distances_comm, distances_many, frequencies_reshaped[modes,:], EIGVECS, modes, ZQS_proj_reshaped)
+        ZQS_proj_interp = util.interpol_spectrum(ks_path, freq, freqs_from_spectrum, distances_comm, distances_many, frequencies_reshaped, EIGVECS_0K, modes, ZQS_proj_reshaped)
     else:
-        ZQS_proj_interp = ZQS_proj_reshaped[:,range(len(modes)),:]
+        ZQS_proj_interp = ZQS_proj_reshaped[:,:,:]
         
     # if (interp>0):
     #     ZQS_proj_interp = util.aaa_interpol_spectrum(ks_path, freq, freqs_from_spectrum, EIGVECS_0K, modes, ZQS_proj_reshaped, interp)
